@@ -16,7 +16,7 @@ from orangewidget.settings import Setting, SettingProvider
 from orangewidget.tests.base import WidgetTest
 from orangewidget.utils.signals import summarize, PartialSummary
 from orangewidget.widget import OWBaseWidget, Msg, StateInfo, Input, Output
-from orangewidget.utils.messagewidget import MessagesWidget
+from orangewidget.utils.messagewidget import InOutStateWidget
 
 
 class DummyComponent(OWComponent):
@@ -36,6 +36,14 @@ class MyWidget(OWBaseWidget):
         self.widget = None
 
 
+class SignalTypeA:
+    pass
+
+
+class SignalTypeB:
+    pass
+
+
 class WidgetTestCase(WidgetTest):
     def test_setattr(self):
         widget = self.create_widget(MyWidget)
@@ -119,6 +127,18 @@ class WidgetTestCase(WidgetTest):
         self.assertFalse((w2.restoreGeometryAndLayoutState(QByteArray())))
         self.assertFalse(w2.restoreGeometryAndLayoutState(QByteArray(b'ab')))
 
+    def test_resizing_disabled_width_hint(self):
+        class TestWidget(OWBaseWidget):
+            name = "Test"
+            resizing_enabled = False
+            want_main_area = True
+        w = TestWidget()
+        w._OWBaseWidget__setControlAreaVisible(False)
+        sm1 = w.maximumSize()
+        w._OWBaseWidget__setControlAreaVisible(True)
+        sm2 = w.maximumSize()
+        self.assertLess(sm1.width() + 30, sm2.width())
+
     def test_garbage_collect(self):
         widget = MyWidget()
         ref = weakref.ref(widget)
@@ -414,45 +434,40 @@ class WidgetTestInfoSummary(WidgetTest):
     def test_io_summaries(self):
         w = MyWidget()
         info = w.info  # type: StateInfo
-        inmsg = w.findChild(MessagesWidget, "input-summary")  # type: MessagesWidget
-        outmsg = w.findChild(MessagesWidget, "output-summary")  # type: MessagesWidget
-        self.assertEqual(len(inmsg.messages()), 0)
-        self.assertEqual(len(outmsg.messages()), 0)
+        inmsg: InOutStateWidget = w.findChild(InOutStateWidget, "input-summary")
+        outmsg: InOutStateWidget = w.findChild(InOutStateWidget, "output-summary")
+        self.assertFalse(inmsg.message)
+        self.assertFalse(outmsg.message)
 
         w.info.set_input_summary(w.info.NoInput)
         w.info.set_output_summary(w.info.NoOutput)
-
-        self.assertEqual(len(inmsg.messages()), 1)
-        self.assertFalse(inmsg.summarize().isEmpty())
-        self.assertEqual(len(outmsg.messages()), 1)
-        self.assertFalse(outmsg.summarize().isEmpty())
+        self.assertTrue(inmsg.message.text)
+        self.assertTrue(outmsg.message.text)
 
         info.set_input_summary("Foo")
 
-        self.assertEqual(len(inmsg.messages()), 1)
-        self.assertEqual(inmsg.summarize().text, "Foo")
-        self.assertFalse(inmsg.summarize().icon.isNull())
+        self.assertTrue(inmsg.message)
+        self.assertEqual(inmsg.message.text, "Foo")
 
         info.set_input_summary(12_345)
         info.set_output_summary(1234)
 
-        self.assertEqual(inmsg.summarize().text, "12.3k")
-        self.assertEqual(inmsg.summarize().informativeText, "12345")
-        self.assertEqual(outmsg.summarize().text, "1234")
+        self.assertEqual(inmsg.message.text, "12.3k")
+        self.assertEqual(inmsg.message.informativeText, "12345")
+        self.assertEqual(outmsg.message.text, "1234")
 
         info.set_input_summary("Foo", "A foo that bars",)
 
         info.set_input_summary(None)
         info.set_output_summary(None)
 
-        self.assertTrue(inmsg.summarize().isEmpty())
-        self.assertTrue(outmsg.summarize().isEmpty())
+        self.assertFalse(inmsg.message.text)
+        self.assertFalse(outmsg.message.text)
 
         info.set_output_summary("Foobar", "42")
 
-        self.assertEqual(len(outmsg.messages()), 1)
-        self.assertEqual(outmsg.summarize().text, "Foobar")
-        self.assertFalse(outmsg.summarize().icon.isNull())
+        self.assertTrue(outmsg.message)
+        self.assertEqual(outmsg.message.text, "Foobar")
 
         with self.assertRaises(TypeError):
             info.set_input_summary(None, "a")
@@ -469,10 +484,10 @@ class WidgetTestInfoSummary(WidgetTest):
         info.set_input_summary(1234, "Foo")
         info.set_output_summary(1234, "Bar")
 
-        self.assertEqual(inmsg.summarize().text, "1234")
-        self.assertEqual(inmsg.summarize().informativeText, "Foo")
-        self.assertEqual(outmsg.summarize().text, "1234")
-        self.assertEqual(outmsg.summarize().informativeText, "Bar")
+        self.assertEqual(inmsg.message.text, "1234")
+        self.assertEqual(inmsg.message.informativeText, "Foo")
+        self.assertEqual(outmsg.message.text, "1234")
+        self.assertEqual(outmsg.message.informativeText, "Bar")
 
     def test_format_number(self):
         self.assertEqual(StateInfo.format_number(9999), "9999")
@@ -484,13 +499,26 @@ class WidgetTestInfoSummary(WidgetTest):
         self.assertEqual(StateInfo.format_number(999_999), "1M")
         self.assertEqual(StateInfo.format_number(1_000_000), "1M")
 
+    def test_overriden_handler(self):
+        class TestWidget(OWBaseWidget, openclass=True):
+            class Inputs(OWBaseWidget.Inputs):
+                inputA = Input("a", SignalTypeA)
 
-class SignalTypeA:
-    pass
+            @Inputs.inputA
+            def handler(self, _):
+                pass
 
+        class DerivedWidget(TestWidget):
+            name = "tw"
 
-class SignalTypeB:
-    pass
+            @TestWidget.Inputs.inputA
+            def handler(self, obj):
+                super().handler(obj)
+
+        widget = self.create_widget(DerivedWidget)
+        widget.set_partial_input_summary = MagicMock()
+        self.send_signal(widget.Inputs.inputA, SignalTypeA())
+        widget.set_partial_input_summary.assert_called_once()
 
 
 @summarize.register(SignalTypeA)
